==> GrufSpaces-0.5.0.tar.gz: GrufSpaces/Extensions/Install.py <==
from Products.GrufSpaces import grufspaces_globals
from StringIO import StringIO
from Products.CMFCore.utils import getToolByName
from Products.CMFCore.DirectoryView import addDirectoryViews
from Acquisition import aq_base
from OFS.Folder import manage_addFolder
from Products.CMFCore.CMFCorePermissions import setDefaultRoles
from Products.GrufSpaces.global_symbols import *
from Products.ExternalMethod.ExternalMethod import ExternalMethod
from Products.CMFPlone.migrations.migration_util import addLinesToProperty
from Products.GrufSpaces.config import GLOBALS, PROJECTNAME

SKIN_NAME = "grufspaces"
_globals = globals()

GroupSpace_workflows = (
        ('groupspace_open_close_workflow', ('GroupSpace'), 0),
        )

GroupSpace_portlets = (
       'here/portlet_groups/macros/portlet',
       'here/portlet_visitor_groups/macros/portlet',
       'here/portlet_groupspaces_changes/macros/portlet',
       )

def install_plone(self, out):
    pass

def install_subskin(self, out, skin_name=SKIN_NAME, globals=grufspaces_globals):
    print >>out, "  Installing subskin."
    skinstool=getToolByName(self, 'portal_skins')
    if skin_name not in skinstool.objectIds():
        print >>out, "    Adding directory view for GRUF"
        addDirectoryViews(skinstool, 'skins', globals)

    for skinName in skinstool.getSkinSelections():
        path = skinstool.getSkinPath(skinName) 
        path = [i.strip() for i in  path.split(',')]
        try:
            if skin_name not in path:
                path.insert(path.index('custom') +1, skin_name)
        except ValueError:
            if skin_name not in path:
                path.append(skin_name)  

        path = ','.join(path)
        skinstool.addSkinSelection( skinName, path)
    print >>out, "  Done installing subskin."

def walk(out, obj, operation):
    if obj.isPrincipiaFolderish:
        for content in obj.objectValues():
            walk(out, content, operation)
    operation(out, obj)


def setupCustomSlots(self, out):
   """ sets up the custom slots"""
   for slot in GroupSpace_portlets: 
       if hasattr(self, "right_slots"):
           if slot in self.right_slots:
               out.write("Right slot exists already\n")
           else:
               right_slots_list=list(self.right_slots)
               self._delProperty('right_slots')
               right_slots_list.append(slot)
               self._setProperty('right_slots',tuple(right_slots_list),'lines')
               out.write("Added %s slot\n" % (slot, ))
                   
def install(self):

    out = StringIO()
    print >>out, "Installing GroupUserFolder"
    install_subskin(self, out)
    install_plone(self, out)
    print >>out, "Done."

    if not hasattr(self.portal_properties, 'grufspaces_properties'):
        self.portal_properties.addPropertySheet('grufspaces_properties', 'GrufSpaces properties')
    
    props = self.portal_properties.grufspaces_properties
        
    grufspaces_properties = (
        ('user_search_in_grufspaces', 'boolean', 1),
        ('group_search_in_grufspaces', 'boolean', 0),
    )
    for prop_id, prop_type, prop_value in grufspaces_properties:
        if not hasattr(props, prop_id):
            props._setProperty(prop_id, prop_value, prop_type)

    print >>out, 'Installing GrufSpaces Configlet'
    
    # Install configlet
    cptool = getToolByName(self, 'portal_controlpanel')
    try:
        cptool.unregisterConfiglet(grufspaces_prefs_configlet['id'])
    except:
        pass
    try:
        cptool.registerConfiglet(**grufspaces_prefs_configlet)
    except:
        pass

    from Products.GrufSpaces.Installation import Installation
    installation = Installation(self)
    if installation.isPlone2():
        print >>out, "Installing GroupSpace features"
        from Products.GrufSpaces import GroupSpace

        installation.setupTypesandSkins((GroupSpace.factory_type_information,), "", grufspaces_globals)

        new_install=0

        if not "GroupVisitor" in installation.root.userdefined_roles():
            new_install=1
            installation.root._addRole("GroupVisitor")
        if not "GroupMember" in installation.root.userdefined_roles():
            new_install=1
            installation.root._addRole("GroupMember")
        if not "GroupAdmin" in installation.root.userdefined_roles():
            new_install=1
            installation.root._addRole("GroupAdmin")
        if not "GroupLeader" in installation.root.userdefined_roles():
            new_install=1
            installation.root._addRole("GroupLeader")

        if new_install:
            perms_list_1 = (GroupSpace_addPermission,)
            perms_list_2 = (GroupSpace_assignRolePermission, GroupSpace_editPermission,)
            perms_list_3 = (GroupSpace_sendMailPermission, )

            installation.setPermissions(perms_list_1, roles=['Manager',])
            installation.setPermissions(perms_list_2, roles = ['Manager','GroupLeader', 'GroupAdmin',])
            installation.setPermissions(perms_list_3, roles = ['Manager','GroupLeader', 'GroupAdmin','GroupMember',])

        catalog = getToolByName(self, 'portal_catalog')
        if not "listGroupSpaceMemberUsers" in catalog.indexes():
            print >>out, "Adding GroupSpace-related indexes"
            catalog.manage_addIndex('listGroupSpaceMemberUsers', 'KeywordIndex', )
        if not "listGroupSpaceVisitorUsers" in catalog.indexes():
            print >>out, "Adding GroupSpace-related indexes"
            catalog.manage_addIndex('listGroupSpaceVisitorUsers', 'KeywordIndex', )
        if not "getGroupSpaceId" in catalog.indexes():
            catalog.manage_addIndex('getGroupSpaceId', 'FieldIndex', )
        wf_tool = installation.root.portal_workflow
        
        # DEPRECATED
        #if not "groupspace_workflow" in wf_tool.objectIds():
        #    print >>out, "Installing GroupSpace-specific Workflow"
        #    wf_tool._importObjectFromFile(GroupSpace.DATA_PATH, verify = 1, set_owner = 1)
        #    wf_tool.setChainForPortalTypes(('GroupSpace',), 'groupspace_workflow')
        
        
        # OPEN CLOSE WORKFLOW
        # Adding the worflows

        for name, types, default in GroupSpace_workflows:
            if name not in wf_tool.objectIds():
                installFunc = ExternalMethod('temp', 'temp', 'GrufSpaces' + '.' + name,
                                             'create' + name.capitalize())
                workflow = installFunc(name)
                wf_tool._setObject(name, workflow)
                if types:
                    wf_tool.setChainForPortalTypes(types, name)
                if default:
                    wf_tool.setDefaultChain(name)
        
        
        installation.root.portal_groups.setGroupWorkspaceType("GroupSpace")
        setupCustomSlots(self, out)
        
        # register GroupSpace in use_folder_contents
        props = self.portal_properties.site_properties
        use_folder_tabs = list(props.use_folder_tabs)
        if 'GroupSpace' not in use_folder_tabs:
            use_folder_tabs.append('GroupSpace')
            props.use_folder_tabs=tuple(use_folder_tabs)
        
        pp=getToolByName(self,'portal_properties')
        p = getattr(pp , 'navtree_properties', None)

        if 'GroupVisitor' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupVisitor')
        if 'GroupMember' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupMember')
        if 'GroupAdmin' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupAdmin')
        if 'GroupLeader' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupLeader')


        provider = getToolByName(self, 'portal_selenium', None)
        if provider:
            # Functional Tests
            action = {'id':PROJECTNAME.lower(),
                      'name':PROJECTNAME,
                      'action':'string:here/get_%s_ftests'%PROJECTNAME.lower(),
                      'condition': '',
                      'permission': 'View',
                      'category':'ftests',
                      'visible': 1}
            provider.addAction(**action)
            print >>out, "Action '%s' added to '%s' action provider" % (str(action['id']), 'portal_selenium')
                   
        print >>out, installation.report()
        print >>out, "Done."



    # return out.getvalue()

def uninstallPortlets(self, portlet_name):
    try:
        portlets = list(self.getProperty(portlet_name))
    except:
        pass
    for portlet in GroupSpace_portlets:
        try:
            portlets.remove(portlet)
        except:
            pass
    self.manage_changeProperties({portlet_name: portlets})
    return

def uninstall(self):
    out = StringIO()
    
    from Products.GrufSpaces.Installation import Installation
    installation = Installation(self)
    
    if installation.isPlone2():
        wf_tool = installation.root.portal_workflow
        # uninstall workflows
        
        for workflow_id, types, default in GroupSpace_workflows:
            if workflow_id in wf_tool.objectIds():
                wf_tool._delObject(workflow_id)

    uninstallPortlets(self, 'left_slots')
    uninstallPortlets(self, 'right_slots')

==> GrufSpaces-0.6.tar.gz: GrufSpaces/Extensions/Install.py <==
from Products.GrufSpaces import grufspaces_globals
from StringIO import StringIO
from Products.CMFCore.utils import getToolByName
from Products.CMFCore.DirectoryView import addDirectoryViews
from Acquisition import aq_base
from OFS.Folder import manage_addFolder
from Products.CMFCore.CMFCorePermissions import setDefaultRoles
from Products.GrufSpaces.global_symbols import *
from Products.ExternalMethod.ExternalMethod import ExternalMethod
from Products.CMFPlone.migrations.migration_util import addLinesToProperty
from Products.GrufSpaces.config import GLOBALS, PROJECTNAME

SKIN_NAME = "grufspaces"
_globals = globals()

GroupSpace_workflows = (
        ('groupspace_open_close_workflow', ('GroupSpace'), 0),
        )

GroupSpace_portlets = (
       'here/portlet_groups/macros/portlet',
       'here/portlet_visitor_groups/macros/portlet',
       'here/portlet_groupspaces_changes/macros/portlet',
       )

def setupCustomSlots(self, out):
   """ sets up the custom slots"""
   for slot in GroupSpace_portlets: 
       if hasattr(self, "right_slots"):
           if slot in self.right_slots:
               out.write("Right slot exists already\n")
           else:
               right_slots_list=list(self.right_slots)
               self._delProperty('right_slots')
               right_slots_list.append(slot)
               self._setProperty('right_slots',tuple(right_slots_list),'lines')
               out.write("Added %s slot\n" % (slot, ))
                   
def install(self):
    out = StringIO()
    if not hasattr(self.portal_properties, 'grufspaces_properties'):
        self.portal_properties.addPropertySheet('grufspaces_properties', 'GrufSpaces properties')
    
    props = self.portal_properties.grufspaces_properties
        
    grufspaces_properties = (
        ('user_search_in_grufspaces', 'boolean', 1),
        ('group_search_in_grufspaces', 'boolean', 0),
    )
    for prop_id, prop_type, prop_value in grufspaces_properties:
        if not hasattr(props, prop_id):
            props._setProperty(prop_id, prop_value, prop_type)

    print >>out, 'Installing GrufSpaces Configlet'
    
    # Install configlet
    cptool = getToolByName(self, 'portal_controlpanel')
    try:
        cptool.unregisterConfiglet(grufspaces_prefs_configlet['id'])
    except:
        pass
    try:
        cptool.registerConfiglet(**grufspaces_prefs_configlet)
    except:
        pass

    from Products.GrufSpaces.Installation import Installation
    installation = Installation(self)
    if installation.isPlone2():
        print >>out, "Installing GroupSpace features"
        from Products.GrufSpaces import GroupSpace

        installation.setupTypesandSkins((GroupSpace.factory_type_information,),
                                        "grufspaces",
                                        grufspaces_globals)

        new_install=0

        if not "GroupVisitor" in installation.root.userdefined_roles():
            new_install=1
            installation.root._addRole("GroupVisitor")
        if not "GroupMember" in installation.root.userdefined_roles():
            new_install=1
            installation.root._addRole("GroupMember")
        if not "GroupAdmin" in installation.root.userdefined_roles():
            new_install=1
            installation.root._addRole("GroupAdmin")
        if not "GroupLeader" in installation.root.userdefined_roles():
            new_install=1
            installation.root._addRole("GroupLeader")

        if new_install:
            perms_list_1 = (GroupSpace_addPermission,)
            perms_list_2 = (GroupSpace_assignRolePermission, )
            perms_list_3 = (GroupSpace_sendMailPermission, )

            installation.setPermissions(perms_list_1, roles=['Manager',])
            installation.setPermissions(perms_list_2, roles = ['Manager','GroupLeader', 'GroupAdmin',])
            installation.setPermissions(perms_list_3, roles = ['Manager','GroupLeader', 'GroupAdmin','GroupMember',])

        catalog = getToolByName(self, 'portal_catalog')
        if not "listGroupSpaceMemberUsers" in catalog.indexes():
            print >>out, "Adding GroupSpace-related indexes"
            catalog.manage_addIndex('listGroupSpaceMemberUsers', 'KeywordIndex', )
        if not "listGroupSpaceVisitorUsers" in catalog.indexes():
            print >>out, "Adding GroupSpace-related indexes"
            catalog.manage_addIndex('listGroupSpaceVisitorUsers', 'KeywordIndex', )
        wf_tool = installation.root.portal_workflow
        
        for name, types, default in GroupSpace_workflows:
            if name not in wf_tool.objectIds():
                installFunc = ExternalMethod('temp', 'temp', 'GrufSpaces' + '.' + name,
                                             'create' + name.capitalize())
                workflow = installFunc(name)
                wf_tool._setObject(name, workflow)
                if types:
                    wf_tool.setChainForPortalTypes(types, name)
                if default:
                    wf_tool.setDefaultChain(name)
        
        
        installation.root.portal_groups.setGroupWorkspaceType("GroupSpace")
        setupCustomSlots(self, out)
        
        # register GroupSpace in use_folder_contents
        props = self.portal_properties.site_properties
        use_folder_tabs = list(props.use_folder_tabs)
        if 'GroupSpace' not in use_folder_tabs:
            use_folder_tabs.append('GroupSpace')
            props.use_folder_tabs=tuple(use_folder_tabs)
        
        pp=getToolByName(self,'portal_properties')
        p = getattr(pp , 'navtree_properties', None)

        if 'GroupVisitor' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupVisitor')
        if 'GroupMember' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupMember')
        if 'GroupAdmin' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupAdmin')
        if 'GroupLeader' not in p.rolesSeeUnpublishedContent:
            addLinesToProperty(p, 'rolesSeeUnpublishedContent', 'GroupLeader')


        provider = getToolByName(self, 'portal_selenium', None)
        if provider:
            # Functional Tests
            action = {'id':PROJECTNAME.lower(),
                      'name':PROJECTNAME,
                      'action':'string:here/get_%s_ftests'%PROJECTNAME.lower(),
                      'condition': '',
                      'permission': 'View',
                      'category':'ftests',
                      'visible': 1}
            provider.addAction(**action)
            print >>out, "Action '%s' added to '%s' action provider" % (str(action['id']), 'portal_selenium')
                   
        print >>out, installation.report()
        print >>out, "Done."



    # return out.getvalue()

def uninstallPortlets(self, portlet_name):
    try:
        portlets = list(self.getProperty(portlet_name))
    except:
        pass
    for portlet in GroupSpace_portlets:
        try:
            portlets.remove(portlet)
        except:
            pass
    self.manage_changeProperties({portlet_name: portlets})
    return

def uninstall(self):
    out = StringIO()
    
    from Products.GrufSpaces.Installation import Installation
    installation = Installation(self)
    
    if installation.isPlone2():
        wf_tool = installation.root.portal_workflow
        # uninstall workflows
        
        for workflow_id, types, default in GroupSpace_workflows:
            if workflow_id in wf_tool.objectIds():
                wf_tool._delObject(workflow_id)

    uninstallPortlets(self, 'left_slots')
    uninstallPortlets(self, 'right_slots')
